==> kdegames-3.1.3.tar.bz2: kdegames-3.1.3/kasteroids/toplevel.h <==
/*
 * KAsteroids - Copyright (c) Martin R. Jones 1997
 *
 * Part of the KDE project
 */

#ifndef __KAST_TOPLEVEL_H__
#define __KAST_TOPLEVEL_H__

#include <kmainwindow.h>
#include <kaccel.h>
#include <qdict.h>
#include <qmap.h>

#include "view.h"

//#define KA_ENABLE_SOUND

class KALedMeter;
class QLCDNumber;

class KAstTopLevel : public KMainWindow
{
    Q_OBJECT
public:
    KAstTopLevel();
    virtual ~KAstTopLevel();

private:
    void initKAction();
    void playSound( const char *snd );
    void readSoundMapping();
    void doStats();

protected:
    virtual void keyPressEvent( QKeyEvent *event );
    virtual void keyReleaseEvent( QKeyEvent *event );
    virtual void focusInEvent( QFocusEvent *event );
    virtual void focusOutEvent( QFocusEvent *event );

private slots:
    void readSettings(); // it is useful as a slot
    void slotNewGame();
    void slotGameOver();
    void slotQuit();

    void slotShipKilled();
    void slotRockHit( int size );
    void slotRocksRemoved();

    void slotUpdateVitals();

    void slotKeyConfig();
    void slotPref();
    void slotShowHighscores();

    void slotPause();

private:
    KAsteroidsView *view;
    QLCDNumber *scoreLCD;
    QLCDNumber *levelLCD;
    QLCDNumber *shipsLCD;

    QLCDNumber *teleportsLCD;
//    QLCDNumber *bombsLCD;
    QLCDNumber *brakesLCD;
    QLCDNumber *shieldLCD;
    QLCDNumber *shootLCD;
    KALedMeter *powerMeter;

    bool   sound;
    QDict<QString> soundDict;

    // waiting for user to press Enter to launch a ship
    bool waitShip;
    bool isPaused;
    bool gameOver;

    int shipsRemain;
    int score;
    int level;
    bool showHiscores;

    enum Action { Invalid, Launch, Thrust, RotateLeft, RotateRight, Shoot, 
                    Teleport, Brake, Shield };

    QMap<Action, KAction*> keycodes;
};

#endif

==> kdegames-3.1.4.tar.bz2: kdegames-3.1.4/kasteroids/toplevel.h <==
/*
 * KAsteroids - Copyright (c) Martin R. Jones 1997
 *
 * Part of the KDE project
 */

#ifndef __KAST_TOPLEVEL_H__
#define __KAST_TOPLEVEL_H__

#include <kmainwindow.h>
#include <kaccel.h>
#include <qdict.h>
#include <qmap.h>

#include "view.h"

//#define KA_ENABLE_SOUND

class KALedMeter;
class QLCDNumber;

class KAstTopLevel : public KMainWindow
{
    Q_OBJECT
public:
    KAstTopLevel();
    virtual ~KAstTopLevel();

private:
    void initKAction();
    void playSound( const char *snd );
    void readSoundMapping();
    void doStats();
    bool processKeyPress( QKeyEvent *event );
    bool processKeyRelease( QKeyEvent *event );


protected:
    virtual bool eventFilter( QObject *object, QEvent *event );
    virtual void focusInEvent( QFocusEvent *event );
    virtual void focusOutEvent( QFocusEvent *event );

private slots:
    void readSettings(); // it is useful as a slot
    void slotNewGame();
    void slotGameOver();
    void slotQuit();

    void slotShipKilled();
    void slotRockHit( int size );
    void slotRocksRemoved();

    void slotUpdateVitals();

    void slotKeyConfig();
    void slotPref();
    void slotShowHighscores();

    void slotPause();
    void slotLaunch();

private:
    KAsteroidsView *view;
    QLCDNumber *scoreLCD;
    QLCDNumber *levelLCD;
    QLCDNumber *shipsLCD;

    QLCDNumber *teleportsLCD;
//    QLCDNumber *bombsLCD;
    QLCDNumber *brakesLCD;
    QLCDNumber *shieldLCD;
    QLCDNumber *shootLCD;
    KALedMeter *powerMeter;

    bool   sound;
    QDict<QString> soundDict;

    // waiting for user to press Enter to launch a ship
    bool waitShip;
    bool isPaused;
    bool gameOver;

    int shipsRemain;
    int score;
    int level;
    bool showHiscores;

    enum Action { Invalid, Launch, Thrust, RotateLeft, RotateRight, Shoot, 
                    Teleport, Brake, Shield };

    QMap<Action, KAction*> keycodes;

    KAction *launchAction;
};

#endif
